/*global define*/
/*jslint browser:true,vars:true*/
define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!de_epages/multistore/inc/affiliateitems-test.html',
    'jquery',
    'de_epages/multistore/inc/affiliateitems',
    '$ready!'
], function (QUnit, fixture, $, affiliateitems) {
    'use strict';

    var affiliateProductsArray = [],    // array with all IDs of affiliate products (from Master)
        affiliateProductsList = {},     // object with IDs of affiliate products (from Master) as keys
        batchAction = "Assign",
        richtable,
        activeRows;

    // mark some products as affiliate
    affiliateProductsArray.push({id: 18036});
    affiliateProductsList[18036] = true;

    affiliateProductsArray.push({id: 18030});
    affiliateProductsList[18030] = true;

    affiliateProductsArray.push({id: 18023});
    affiliateProductsList[18023] = true;

    affiliateProductsArray.push({id: 18035});
    affiliateProductsList[18035] = true;

    affiliateProductsArray.push({id: 18034});
    affiliateProductsList[18034] = true;


    QUnit.module("de_epages/multistore/inc/affiliateitems", {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.asyncTest("de_epages/multistore/inc/affiliateitems", function () {
        var checkboxes,
            countDataAttribute = 0,
            countAffiliate = 0;

        richtable = $('.ContentList');
        checkboxes = richtable.find('input[type=checkbox][name=ListObjectID]');

        // count items with undefined data attribute
        checkboxes.each(function (index, item) {
            if ($(item).data('isAffiliate') !== undefined) {
                countDataAttribute++;
            }
        });

        QUnit.equal(
            countDataAttribute,
            0,
            "In initial state of the richtable all checkboxes are not marked as affiliate items"
        );

        // initialize checkboxes
        affiliateitems
            .init(affiliateProductsList)
            .addDataToItems(checkboxes);

        // reset counter for data attribute
        countDataAttribute = 0;

        // count items with data attribute 'isAffiliate' to true
        checkboxes.each(function (index, item) {
            if ($(item).data('isAffiliate') !== undefined) {
                countDataAttribute++;

                if ($(item).data('isAffiliate')) {
                    countAffiliate++;
                }
            }
        });

        QUnit.equal(
            countDataAttribute,
            checkboxes.length,
            "After running init method, all checkboxes contain an data attribute 'isAffiliate'"
        );

        QUnit.equal(
            countAffiliate,
            affiliateProductsArray.length,
            "Number of affiliate products: " + affiliateProductsArray.length
        );

        // check first checkbox (no affiliate item) and call method to disable "Assign"-BatchAction
        checkboxes.first().prop('checked', true);
        activeRows =  richtable.find('tbody tr td:first-child input[type=checkbox]:checked');
        affiliateitems.disableBatchAction(activeRows, batchAction);

        QUnit.equal(
            $('.ep-batchActions-groupImage-' + batchAction).closest('label').hasClass('BatchActionDisabled'),
            false,
            "No affiliate item is checked, therefore no BatchAction is disabled."
        );

        // check last checkbox (affiliate item) and call method to disable "Assign"-BatchAction
        checkboxes.last().prop('checked', true);
        activeRows =  richtable.find('tbody tr td:first-child input[type=checkbox]:checked');
        affiliateitems.disableBatchAction(activeRows, batchAction);

        QUnit.equal(
            $('.ep-batchActions-groupImage-' + batchAction).closest('label').hasClass('BatchActionDisabled'),
            true,
            "At least one affiliate item is checked, therefore 'Assign'-BatchAcion is disabled."
        );

        QUnit.start();
    });
});